/* ***************************************************************************
   *                                                                         *
   *   Kindermann                                   WPK-Produktentwicklung   *
   *                                                Schuljahr 2016/17        *
   *                                                                         *
   *                             WiFiSchalter 2                              *
   *                          für das ESP01-Board                            *
   *                                                                         *
   ***************************************************************************/


#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>
#include <ESP8266mDNS.h>
#include <WiFiManager.h>
#include <WebSocketsServer.h>
#include "index.h"


//LED Status
#include <Ticker.h>
Ticker ticker;

ESP8266WebServer server(80);
WebSocketsServer webSocket=WebSocketsServer(88);
MDNSResponder mdns;

String JSONtxt;
int websockMillis=500;
unsigned long wait001=0UL;

int led1=0, led2=2;
boolean LED1onoff=true, LED2onoff=false;


void tick()
{
  //Toggle Status
  int state = digitalRead(led1);
  digitalWrite(led1, !state);
}

void configModeCallback (WiFiManager *myWiFiManager) {
   //Konfigurationsmodus -> LED blinkt schneller!
  ticker.attach(0.2, tick);
}


void webSocketEvent(uint8_t num, WStype_t type, uint8_t * payload, size_t wslength){
  String payloadString=(const char *)payload;
  
  if(type==WStype_TEXT){
    byte separator=payloadString.indexOf('=');
    String var=payloadString.substring(0,separator);
    String val=payloadString.substring(separator+1);
       
    if(var=="LED1onoff"){           
      if(val=="LED1 = ON")
        {
        LED1onoff=true;
        digitalWrite(led1,LOW);
        }
      else
        {
        LED1onoff=false;
        digitalWrite(led1,HIGH);        
        }
      }  
        if(var=="LED2onoff"){            
      if(val=="LED2 = ON")
        {
        LED2onoff=true;
        digitalWrite(led2,LOW);
        }
      else
        {
        LED2onoff=false;
        digitalWrite(led2,HIGH);        
        }
      }  
    }    
  }


void setup(void){

  pinMode(led1,OUTPUT);
  digitalWrite(led1,LOW);
  pinMode(led2,OUTPUT);
  digitalWrite(led2,HIGH);
 

  // Ticker starten und Verbindung aufbauen ...
  ticker.attach(0.6, tick);

  WiFiManager wifiManager;
  
  delay(2000);
 
  // überprüfen, ob Tx und Rx gebrückt sind ...
  pinMode(1, OUTPUT);       // TX
  pinMode(3, INPUT_PULLUP); // Rx
  digitalWrite(1, 1);
  delayMicroseconds(2);
  if (!digitalRead(3))goto weiter;

  digitalWrite(1, 0);
  delayMicroseconds(2);
  if (digitalRead(3))goto weiter;
  wifiManager.resetSettings();
  weiter:

  WiFi.hostname("WiFiSchalter");
  
  //Access-Point-Modus
  wifiManager.setAPCallback(configModeCallback);

  //SSID und Passwort laden und einloggen ...
  if (!wifiManager.autoConnect()) {
    ESP.reset();
    delay(1000);
  }
        
  //WiFi-Verbindung hergestellt !
  ticker.detach();
  //LED eingeschaltet lassen ...
  digitalWrite(led1, LOW);
  digitalWrite(1, HIGH);

  mdns.begin("WiFiSchalter", WiFi.localIP());
      
  server.on("/", [](){
    server.send(200, "text/html",MAIN_page);
  });
  
  server.begin();
  webSocket.begin();
  webSocket.onEvent(webSocketEvent);  
}
 
void loop(void){
  server.handleClient();
  webSocket.loop();
  
  if(millis()>wait001){
             
      String LEDswitch1="LED1 = OFF";
      if(LED1onoff==true)LEDswitch1="LED1 = ON";
      String LEDswitch2="LED2 = OFF";
      if(LED2onoff==true)LEDswitch2="LED2 = ON";
    
      JSONtxt="{\"LED1onoff\":\""+LEDswitch1+"\","+
              "\"LED2onoff\":\""+LEDswitch2+"\"}";                  
  
      webSocket.broadcastTXT(JSONtxt);
      wait001=millis()+websockMillis;    
      } 
} 


